function [CurrentVideo,AllVelocity,AllChange,AllSmooth,AllACR]=cellStat_v1(cell,Kcount,...
    velocity,AllVelocity,angleChange,AllChange,percentSmooth,AllSmooth,ACR,AllACR,...
    EveryVideoData,CurrentVideo,NumberofVideos,Filename,Outlier_Alpha)


%%% NUMBER OF ACTIVE CELLS
NumberTrajectories=numel(cell.real);        % To estimate number of active cells, find number of active trajectories in first 
ActiveCells=[];                             %  and last frames and find average
for k=[1,Kcount]
    index=0;
    for u=1:NumberTrajectories
        if any(cell.real(u).index(:,2)==k)
            index=index+1;
        end
    end
    ActiveCells(end+1)=index;
end
ActiveCells=round(mean(ActiveCells));


%%% TRAJECTORY STATISTICS
if CurrentVideo==1                          % If first video of series, start enduring data set
    AllVelocity=velocity;
    AllChange=angleChange;
    AllSmooth=percentSmooth;
    AllACR=ACR;
else                                        % Store new video data in enduring data set
    AllVelocity=horzcat(AllVelocity,velocity);
    AllChange=horzcat(AllChange,angleChange);
    AllSmooth=horzcat(AllSmooth,percentSmooth);
    AllACR=horzcat(AllACR,ACR);
end

%%% CRUNCHING DATA
if EveryVideoData && NumberofVideos~=1
    Vmean=mean(velocity);
    Vstdev=std(velocity);
    Vstderr=Vstdev/sqrt(length(velocity));
    Amean=mean(angleChange);
    Astdev=std(angleChange);
    Astderr=Astdev/sqrt(length(angleChange));
    Pmean=mean(percentSmooth);
    Pstdev=std(percentSmooth);
    Pstderr=Pstdev/sqrt(length(percentSmooth));
    Rmed=median(ACR);
    ACR=sort(ACR);
    if mod(length(ACR),2)==0
        R_Q3=median(ACR((length(ACR)/2)+1:end));
        R_Q1=median(ACR(1:(length(ACR)/2)));
    elseif mod(length(ACR),2)==1
        R_Q3=median(ACR((length(ACR)/2)+.5:end));
        R_Q1=median(ACR(1:(length(ACR)/2)-.5));
    end
    R_UpperWhisker=max(AllACR);
    R_LowerWhisker=min(AllACR);
    
    fprintf('\nShowing Results For Video %d/%d: "%s". \n',CurrentVideo,NumberofVideos,Filename);
    h=figure('Name','Results for Single Video');
    ColumnName={'Mean (*Median)' 'Standard Deviation (*Upper Quartile)' 'Standard Error (*Lower Quartile)'};
    RowName={'Video Info (cells,trajectories)' 'Velocity (um/s)' 'RCD (deg/s)' '%S' 'ACR*' 'ACR Whiskers*'};
    Results={ActiveCells,NumberTrajectories,'';Vmean,Vstdev,Vstderr;Amean,Astdev,Astderr;Pmean,Pstdev,Pstderr;...
        Rmed,R_Q3,R_Q1;'',R_UpperWhisker,R_LowerWhisker};
    t=uitable('Data',Results,'ColumnName',ColumnName,'RowName',RowName);
    t.Position(3:4) = t.Extent(3:4);
    h.Position(3:4)=t.Position(3:4)+[50,50];
end

if CurrentVideo==NumberofVideos
    if Outlier_Alpha
        set=1;
        removed=0;
        while set<5
            switch set
                case 1
                    data=AllVelocity;
                case 2
                    data=AllChange;
                case 3
                    data=AllSmooth;
                case 4
                    data=AllACR;
            end
            
            [data1]=outliers(data,Outlier_Alpha);
            
            if length(data1)==length(data)          % If no outliers removed, moves onto next data set
                set=set+1;
            else                                    % Else, continues to removes outliers
                removed=removed+1;
                switch set
                    case 1
                        AllVelocity=data1;
                    case 2
                        AllChange=data1;
                    case 3
                        AllSmooth=data1;
                    case 4
                        AllACR=data1;
                end
            end
        end
        fprintf('%i outliers removed. \n',removed);
    else
        removed=NaN;
    end
    
    
    Vmean=mean(AllVelocity);
    Vstdev=std(AllVelocity);
    Vstderr=Vstdev/sqrt(length(AllVelocity));
    Amean=mean(AllChange);
    Astdev=std(AllChange);
    Astderr=Astdev/sqrt(length(AllChange));
    Pmean=mean(AllSmooth);
    Pstdev=std(AllSmooth);
    Pstderr=Pstdev/sqrt(length(AllSmooth));
    Rmed=median(AllACR);
    AllACR=sort(AllACR);
    if mod(length(AllACR),2)==0
        R_Q3=median(AllACR((length(AllACR)/2)+1:end));
        R_Q1=median(AllACR(1:(length(AllACR)/2)));
    elseif mod(length(AllACR),2)==1
        R_Q3=median(AllACR((length(AllACR)/2)+.5:end));
        R_Q1=median(AllACR(1:(length(AllACR)/2)-.5));
    end
    R_UpperWhisker=max(AllACR);
    R_LowerWhisker=min(AllACR);
    
    if Outlier_Alpha
    fprintf('\nShowing Complete Results For All %d Videos. Outliers Removed!\n',NumberofVideos);
    RowName={'Video Info (cells,trajectories,outliers)' 'Velocity (um/s)' 'RCD (deg/s)' '%S' 'ACR*' 'ACR Whiskers*'};
    Results={ActiveCells,NumberTrajectories,removed;Vmean,Vstdev,Vstderr;Amean,Astdev,Astderr;Pmean,Pstdev,Pstderr;...
        Rmed,R_Q3,R_Q1;'',R_UpperWhisker,R_LowerWhisker};
    else
    fprintf('\nShowing Complete Results For All %d Videos.\n',NumberofVideos);
    RowName={'Video Info (cells,trajectories)' 'Velocity (um/s)' 'RCD (deg/s)' '%S' 'ACR*' 'ACR Whiskers*'};
    Results={ActiveCells,NumberTrajectories,'';Vmean,Vstdev,Vstderr;Amean,Astdev,Astderr;Pmean,Pstdev,Pstderr;...
        Rmed,R_Q3,R_Q1;'',R_UpperWhisker,R_LowerWhisker};
    end
    fprintf('\nShowing Complete Results For All %d Videos. Outliers Removed!\n',NumberofVideos);
    toc
    h=figure('Name','Complete Results for All Videos');
    ColumnName={'Mean (*Median)' 'Standard Deviation (*Upper Quartile)' 'Standard Error (*Lower Quartile)'};
    
    t=uitable('Data',Results,'ColumnName',ColumnName,'RowName',RowName);
    t.Position(3:4) = t.Extent(3:4);
    h.Position(3:4)=t.Position(3:4)+[50,50];
    
    CurrentVideo=1;
else
    CurrentVideo=CurrentVideo+1;
    toc
    fprintf('Please load next video.\n\n');
end


%%% REMOVE OUTLIERS
function [data1]=outliers(data,Outlier_alpha)
n=length(data);

if license('test','Statistics_Toolbox')         % If User has Statistics Toolbox, can be exact
    t=tinv(Outlier_alpha/2,n-2);
    tau=-t*(n-1)/(sqrt(n)*sqrt(n-2+t^2));
else                                            % If User does not, must use alpha=0.01
    fprintf('Note: You do not have Statistics Toolbox installed. Outliers detected using alpha=0.01. \n');
    N=[3:38,40:2:50,55:5:70,80:10:100,200,500,1000,5000];
    Tau=[1.1546,1.4850,1.7150,1.8722,1.9832,2.0649,2.1271,2.1761,2.2155,...
        2.2478,2.2749,2.2979,2.3176,2.3347,2.3497,2.3629,2.3747,2.3853,...
        2.3948,2.4034,2.4112,2.4183,2.4249,2.4309,2.4365,2.4416,2.4464,...
        2.4509,2.4550,2.4589,2.4626,2.4660,2.4692,2.4723,2.4751,2.4778,...
        2.4829,2.4874,2.4915,2.4952,2.4987,2.5018,2.5087,2.5144,2.5192,...
        2.5233,2.5299,2.5351,2.5392,2.5576,2.5686,2.5722,2.5751];
    if n>5000
        tau=Tau(end);
    else
        tau=interp1(N,Tau,n);
    end
end

S=std(data);                            % See: Modified Thompson Tau Method for Outliers
data1=sort(data);
susp1=abs(data1(1)-mean(data));
suspn=abs(data1(n)-mean(data));
if susp1>suspn
    susp=susp1;
    position=1;
else
    susp=suspn;
    position=n;
end
if susp>tau*S
    data1(position)=[];
end



