function [S,C,R,Kcount]=importImages_v1(FrameSeconds,PixelCutoff,DarkBackground)

if FrameSeconds<=0
    error('Please enter in a positive value for FrameSeconds.');
end

%%% IMPORT THE IMAGES
k=1;                                        % k always refers to frame number
RGB=0;
while true
    if k<=9                                 % Create an image filename
        trop=['00' num2str(k)];
        trop_alt=['0' num2str(k)];
        trop_2nd_alt=num2str(k);
    elseif k>=10 && k<=99
        trop=['0' num2str(k)];
        trop_alt=num2str(k);
    elseif k>=100
        trop=num2str(k);
    end
    jpgFileName=strcat('image',trop,'.jpg');
    jpgFileName_alt=strcat('image',trop_alt,'.jpg');
    jpgFileName_2nd_alt=strcat('image',trop_2nd_alt,'.jpg');
    
    if exist(jpgFileName,'file')            % See if it exists
    elseif exist(jpgFileName_alt,'file')
        jpgFileName=jpgFileName_alt;
    elseif exist(jpgFileName_2nd_alt,'file')
        jpgFileName=jpgFileName_2nd_alt;
    elseif k==1                             % It doesn't exist
        msg=sprintf(['\nERROR! This folder does not contain your video!\n'...
            'Please make sure you are in the correct folder and your image files are properly formatted. \n']);
        error(msg);
    else                                    % Final frame has been reached
        fprintf('There are %d frames. %.1f seconds total.\n',k-1,(k-2)*FrameSeconds);
        break
    end
    
	imageData=imread(jpgFileName);          % It exists, so read the image
    if size(imageData,3)>1                  % Check if RGB or Gray
     	L(:,:,k*3-2:k*3)=imageData;
     	imageData=rgb2gray(imageData);      % If RGB, convert to Gray
      	RGB=1;
    end
    S(:,:,k)=imageData;                     % Save to S (master matrix), S later becomes binary
    k=k+1;                                  % Looks for next image
end
Kcount=k-1;                                 % Kcount is number of frames

% INTENSITY CUTOFF
if RGB                                      % C contains original images
    C=L;                                    % 3 planes per image required if RGB
else
    C=S;                                    % 1 plane per image for Grayscale
end

% DARK OR BRIGHT FIELD                      % Allows us to treat S the same despite bright or dark background          
if ~DarkBackground                          
    S=255-S;
end

R=mat2gray(S);                              % R is grayscale copy of S


for k=1:Kcount                              % Converting S to binary
    if PixelCutoff                          % User designated Otsu's Method
        S(:,:,k)=im2bw(S(:,:,k),PixelCutoff/255);
    else                                    % User designated a specific grayscale cutoff
        level=graythresh(S(:,:,k));
        S(:,:,k)=im2bw(S(:,:,k),level);
    end
end
S=logical(S);                               % Converting S to logical format
