function roseGraph_v1(cell,FrameSeconds,NmPixel,RoseSeconds,RoseAxis,RoseTrajNumber,RoseFirst)

if RoseSeconds<=0
    error('Please enter in a positive value for RoseSeconds.');
end
if RoseAxis<=0
    error('Please enter in a positive value for RoseAxis.');
end

RoseFrames=round(RoseSeconds/FrameSeconds);     % Convert seconds to frames
roseY=zeros(RoseFrames,numel(cell.real));       % Hold centroid data for display
roseX=zeros(RoseFrames,numel(cell.real));

%%% BUILDING DATA TO DISPLAY
index=0;
if RoseFirst
    for u=1:numel(cell.real)
        if length(cell.real(u).track)>=RoseFrames && ~any(isnan(cell.real(u).track(1:RoseFrames,1)))
            index=index+1;
            roseY(1:RoseFrames,index)=(cell.real(u).track(1:RoseFrames,1)-cell.real(u).track(1,1))*NmPixel/1000;
            roseX(1:RoseFrames,index)=(cell.real(u).track(1:RoseFrames,2)-cell.real(u).track(1,2))*NmPixel/1000;
        end
    end
else
    for u=1:numel(cell.real)
        if length(cell.real(u).track)>=RoseFrames && ~any(isnan(cell.real(u).track(end-RoseFrames+1:end,1)))
            index=index+1;
            randomstart=randi(length(cell.real(u).track)-RoseFrames+1);     % Randomize start point
            roseY(1:RoseFrames,index)=(cell.real(u).track(randomstart:randomstart+RoseFrames-1,1)...
                        -cell.real(u).track(randomstart,1))*NmPixel/1000;
            roseX(1:RoseFrames,index)=(cell.real(u).track(randomstart:randomstart+RoseFrames-1,2)...
                        -cell.real(u).track(randomstart,2))*NmPixel/1000;
        end
    end
end
roseY(:,index+1:end)=[];
roseX(:,index+1:end)=[];

%%% DISPLAY
rosetitle=sprintf('Rose Graph (%.2f seconds)',RoseSeconds);
figure('Name',rosetitle)
rosetitle=['RoseGraph(' num2str(RoseSeconds) 'sec).eps'];
if ~RoseTrajNumber                                          % Show all trajectories
    set(gca,'FontSize',15)
    plot(roseY,roseX,'Color','k');
    axis([-RoseAxis RoseAxis -RoseAxis RoseAxis])
    saveas(gcf,rosetitle,'eps')
elseif index>=RoseTrajNumber                                % If more than enough, randomize which trajectories to show
    randtraj=randperm(index,RoseTrajNumber);
    roseY=roseY(:,randtraj);
    roseX=roseX(:,randtraj);
    set(gca,'FontSize',15)
    plot(roseY,roseX,'Color','k');
    axis([-RoseAxis RoseAxis -RoseAxis RoseAxis])
    saveas(gcf,rosetitle,'eps')
else                                                        % If not enough trajectories, show all and display warning
    plot(roseX,roseY,'Color','k','LineWidth',0.75);
    set(gca,'FontSize',15)
    axis([-RoseAxis RoseAxis -RoseAxis RoseAxis])
    saveas(gcf,rosetitle,'eps')
    msg=sprintf('NOTE: LESS THAN %.0f TRAJECTORIES FOR ROSE GRAPH. ONLY %.0f TRAJECTORIES DISPLAYED. \n',RoseTrajNumber,index);
    fprintf(msg);
end



